#!/bin/sh


if [ x"$ASPEN_GPU_ID" = x ]; then
	export ASPEN_GPU_ID=0
fi
if [ x"$CUDA_PATH" = x ] || [ ! -e $CUDA_PATH ]; then
	export CUDA_PATH=/usr/local/cuda
fi

export LD_LIBRARY_PATH=$CUDA_PATH/lib64:$LD_LIBRARY_PATH

IN=IN-HPC151
IN_FROM=16
IN_TO=20000
IN_STEP=16
awk 'BEGIN{ print 1; for(i='$IN_FROM';i<='$IN_TO';i+='$IN_STEP'){ print i; } print -1; exit; }' > $IN

GPU=`../src/get_dev_info | awk '/DEVICE/{ gsub(/^[A-Za-z0-9]*-/,"",$2); gsub(/-/,""); print $2; }'`

EXEC='timeout -s KILL 36000 '
OPTIONAL='-HPC152'

ASPEN_V=1.5p6
CUDA_V=7.5
MAGMA_V=1.7.0
KBLAS_V=1.3_beta

EXEC_ASPEN=0
EXEC_CUDA=0
EXEC_MAGMA=1
EXEC_KBLAS=1

ONLY_SYMV=1


if [ $EXEC_ASPEN -ne 0 ]; then
if [ $ONLY_SYMV  -eq 0 ]; then
$EXEC ./test2-sgemv-n $IN | tee log-ASPEN.K2-$ASPEN_V-SGEMVN-$GPU$OPTIONAL
$EXEC ./test2-sgemv-t $IN | tee log-ASPEN.K2-$ASPEN_V-SGEMVT-$GPU$OPTIONAL
$EXEC ./test2-dgemv-n $IN | tee log-ASPEN.K2-$ASPEN_V-DGEMVN-$GPU$OPTIONAL
$EXEC ./test2-dgemv-t $IN | tee log-ASPEN.K2-$ASPEN_V-DGEMVT-$GPU$OPTIONAL
fi
$EXEC ./test2-ssymv-u $IN | tee log-ASPEN.K2-$ASPEN_V-SSYMVU-$GPU$OPTIONAL
$EXEC ./test2-ssymv-l $IN | tee log-ASPEN.K2-$ASPEN_V-SSYMVL-$GPU$OPTIONAL
$EXEC ./test2-dsymv-u $IN | tee log-ASPEN.K2-$ASPEN_V-DSYMVU-$GPU$OPTIONAL
$EXEC ./test2-dsymv-l $IN | tee log-ASPEN.K2-$ASPEN_V-DSYMVL-$GPU$OPTIONAL
fi

if [ $EXEC_CUDA  -ne 0 ]; then
if [ $ONLY_SYMV  -eq 0 ]; then
$EXEC ./cuda-sgemv-n $IN 1 | tee log-CUDA-$CUDA_V-SGEMVN-$GPU$OPTIONAL
$EXEC ./cuda-sgemv-t $IN 1 | tee log-CUDA-$CUDA_V-SGEMVT-$GPU$OPTIONAL
$EXEC ./cuda-dgemv-n $IN 1 | tee log-CUDA-$CUDA_V-DGEMVN-$GPU$OPTIONAL
$EXEC ./cuda-dgemv-t $IN 1 | tee log-CUDA-$CUDA_V-DGEMVT-$GPU$OPTIONAL
fi
$EXEC ./cuda-ssymv-u $IN 1 | tee log-CUDA-$CUDA_V-SSYMVU-$GPU$OPTIONAL
$EXEC ./cuda-ssymv-l $IN 1 | tee log-CUDA-$CUDA_V-SSYMVL-$GPU$OPTIONAL
$EXEC ./cuda-ssymv-u $IN 0 | tee log-CUDA-$CUDA_V-SSYMVUnoAtomic-$GPU$OPTIONAL
$EXEC ./cuda-ssymv-l $IN 0 | tee log-CUDA-$CUDA_V-SSYMVLnoAtomic-$GPU$OPTIONAL
$EXEC ./cuda-dsymv-u $IN 1 | tee log-CUDA-$CUDA_V-DSYMVU-$GPU$OPTIONAL
$EXEC ./cuda-dsymv-l $IN 1 | tee log-CUDA-$CUDA_V-DSYMVL-$GPU$OPTIONAL
$EXEC ./cuda-dsymv-u $IN 0 | tee log-CUDA-$CUDA_V-DSYMVUnoAtomic-$GPU$OPTIONAL
$EXEC ./cuda-dsymv-l $IN 0 | tee log-CUDA-$CUDA_V-DSYMVLnoAtomic-$GPU$OPTIONAL
fi

if [ $EXEC_MAGMA -ne 0 ]; then
if [ $ONLY_SYMV  -eq 0 ]; then
$EXEC ./magma-sgemv-n $IN | tee log-MAGMA-$MAGMA_V-SGEMVN-$GPU$OPTIONAL
$EXEC ./magma-sgemv-t $IN | tee log-MAGMA-$MAGMA_V-SGEMVT-$GPU$OPTIONAL
$EXEC ./magma-dgemv-n $IN | tee log-MAGMA-$MAGMA_V-DGEMVN-$GPU$OPTIONAL
$EXEC ./magma-dgemv-t $IN | tee log-MAGMA-$MAGMA_V-DGEMVT-$GPU$OPTIONAL
fi
$EXEC ./magma-ssymv-u $IN | tee log-MAGMA-$MAGMA_V-SSYMVU-$GPU$OPTIONAL
$EXEC ./magma-ssymv-l $IN | tee log-MAGMA-$MAGMA_V-SSYMVL-$GPU$OPTIONAL
$EXEC ./magma2-ssymv-u $IN | tee log-MAGMA2-$MAGMA_V-SSYMVU-$GPU$OPTIONAL
$EXEC ./magma2-ssymv-l $IN | tee log-MAGMA2-$MAGMA_V-SSYMVL-$GPU$OPTIONAL
$EXEC ./magma-dsymv-u $IN | tee log-MAGMA-$MAGMA_V-DSYMVU-$GPU$OPTIONAL
$EXEC ./magma-dsymv-l $IN | tee log-MAGMA-$MAGMA_V-DSYMVL-$GPU$OPTIONAL
$EXEC ./magma2-dsymv-u $IN | tee log-MAGMA2-$MAGMA_V-DSYMVU-$GPU$OPTIONAL
$EXEC ./magma2-dsymv-l $IN | tee log-MAGMA2-$MAGMA_V-DSYMVL-$GPU$OPTIONAL
fi

if [ $EXEC_KBLAS -ne 0 ]; then
if [ $ONLY_SYMV  -eq 0 ]; then
$EXEC ./kblas-sgemv-n $IN | tee log-KBLAS-$KBLAS_V-SGEMVN-$GPU$OPTIONAL
$EXEC ./kblas-sgemv-t $IN | tee log-KBLAS-$KBLAS_V-SGEMVT-$GPU$OPTIONAL
$EXEC ./kblas-dgemv-n $IN | tee log-KBLAS-$KBLAS_V-DGEMVN-$GPU$OPTIONAL
$EXEC ./kblas-dgemv-t $IN | tee log-KBLAS-$KBLAS_V-DGEMVT-$GPU$OPTIONAL
fi
$EXEC ./kblas-ssymv-u $IN | tee log-KBLAS-$KBLAS_V-SSYMVU-$GPU$OPTIONAL
$EXEC ./kblas-ssymv-l $IN | tee log-KBLAS-$KBLAS_V-SSYMVL-$GPU$OPTIONAL
$EXEC ./kblas-dsymv-u $IN | tee log-KBLAS-$KBLAS_V-DSYMVU-$GPU$OPTIONAL
$EXEC ./kblas-dsymv-l $IN | tee log-KBLAS-$KBLAS_V-DSYMVL-$GPU$OPTIONAL
fi

exit 0

